@@ -1,10 +1,10 @@
 ## ------------------------------------------------------------------------
-datax <- c(1:5,1:5,1:5,1:5,1:5,1:5,1:5,1:5,1:5,1:5,1:5,1:5,1:5,1:5,1:5,1:5,1:5,1:5,1:5,1:5,1:5)
+datax <- sunspots
 
 ## ------------------------------------------------------------------------
 library(PredictTestbench)
 
-## ------------------------------------------------------------------------
+## ----fig.width=7---------------------------------------------------------
 q <- prediction_errors(datax, nextVal = 10)
 q
 plot_predictions(q)
